/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.playlist;

import java.util.ArrayList;
import java.util.List;


/**
 * Holds a PlayList.
 *
 * @author Jordan Reed
 */
public class PlayList {
    /**
     * Holds the original filename of the playlist.
     */
    protected String originalFileName;

    /** Holds the entries in the playlist. */
    protected List playListEntries;

    /**
     * Constructs a new empty playlist.
     */
    public PlayList() {
        playListEntries = new ArrayList();
    }

    /**
     * Sets the name of the original playlist file.
     *
     * @param originalFileName the original playlist file
     */
    public void setOriginalFileName(String originalFileName) {
        this.originalFileName = originalFileName;
    }

    /**
     * Gets the name of the original playlist file.
     *
     * @return the original playlist file
     */
    public String getOriginalFileName() {
        return this.originalFileName;
    }

    /**
     * Adds an entry into the playlist.
     *
     * @param playListEntry a new entry to add to the list
     */
    public void addPlayListEntry(PlayListEntry playListEntry) {
        playListEntries.add(playListEntry);
    }

    /**
     * Returns the number of entries in the list.
     *
     * @return the number of entries in the list
     */
    public int size() {
        return playListEntries.size();
    }

    /**
     * Gets the list of PlayListEntries.
     *
     * @return a list of PlayListEntries
     */
    public List getPlayListEntries() {
        return playListEntries;
    }

    /**
     * Converts the object to a string representation.
     *
     * @return a String representation of the object
     */
    public String toString() {
        StringBuffer sb = new StringBuffer();

        sb.append(getClass().getName());
        sb.append(" [");
        sb.append("playListEntriess=");
        sb.append(this.playListEntries);
        sb.append("]");

        return sb.toString();
    }
}
