/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.playlist;

import java.io.File;


/**
 * Holds a single item entry in a playlist file.
 *
 * @author Jordan Reed
 */
public class PlayListEntry {
    // TODO: This should not exists.  It should only be in the parent
    // PlayList object.

    /** Holds the file of the playlist. */
    protected File playListFile;

    /** Holds the individual file for this entry. */
    protected File playListEntryFile;

    /**
     * Constructs a new playListEntry.
     *
     * @param playListFile the playlist file this entry in inside
     * @param filename the name of the playlist entry
     */
    public PlayListEntry(File playListFile, String filename) {
        this.playListFile = playListFile;
        playListEntryFile = new File(filename);

        if (!playListEntryFile.exists()) {
            String pathCorrectedFilename =
                filename.replace('\\', File.separatorChar).replace(
                    '/', File.separatorChar);
            playListEntryFile =
                new File(
                    playListFile.getParent() + File.separator
                    + pathCorrectedFilename);
        }
    }

    /**
     * Gets back the file for the specific playlist entry.
     *
     * @return the file for the playlist entry
     */
    public File getPlayListEntryFile() {
        return this.playListEntryFile;
    }

    /**
     * Gets the simple name of the file.
     *
     * @return the simple name of the file
     * @see java.io.File#getName
     */
    public String getName() {
        return playListEntryFile.getName();
    }

    /**
     * Gets the absolute name of the file.
     *
     * @return the absolute name of the file
     * @see java.io.File#getAbsolutePath
     */
    public String getAbsolutePath() {
        return playListEntryFile.getAbsolutePath();
    }

    /**
     * Gets the relative name of the file to the containing playlist
     *
     * @return the relative name of the file to the containing playlist
     */
    public String getRelativePath() {
        return getAbsolutePath().substring(
            playListFile.getParentFile().getAbsolutePath().length());
    }
}
