/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.swingui.file;

import java.awt.Component;

import java.io.File;

import java.util.prefs.Preferences;

import javax.swing.JFileChooser;


/**
 * Swing UI to select a directory to export a playlist to.
 *
 * @author Jordan Reed
 */
public class FileExporter {
    /**
     * Holds the preferences constant for the last directory where a playlist
     * was exported to.
     */
    private static final String LAST_EXPORT_DIRECTORY =
        "LAST_EXPORT_DIRECTORY";

    /** Holds the parent component used to make this dialog modal. */
    protected Component parentComponent;

    /**
     * Creates a new FileExporter with the given parent component.
     *
     * @param parentComponent the component to make this modal against.
     */
    public FileExporter(Component parentComponent) {
        this.parentComponent = parentComponent;
    }

    /**
     * Gets the directory to export the playlist to.
     *
     * @return the directory to export the playlist to or null if no
     *         directory is selected
     */
    public File getExportDirectory() {
        JFileChooser fileChooser = new JFileChooser();
        fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        fileChooser.setMultiSelectionEnabled(false);

        File returnFile = null;
        File lastExportDirectory = getLastExportDirectory();

        if (lastExportDirectory != null) {
            fileChooser.setSelectedFile(lastExportDirectory);
        }

        int returnValue = fileChooser.showOpenDialog(parentComponent);

        if (returnValue == JFileChooser.APPROVE_OPTION) {
            returnFile = fileChooser.getSelectedFile();
        }

        if (returnFile != null) {
            setLastExportDirectory(returnFile);
        }

        return returnFile;
    }

    /**
     * Sets the last directory that a user exported a playlist to.
     *
     * @param lastExportDirectory the last directory the user exported
     *        a playlist to.
     */
    protected void setLastExportDirectory(File lastExportDirectory) {
        Preferences preferences =
            Preferences.userNodeForPackage(this.getClass());
        preferences.put(
            LAST_EXPORT_DIRECTORY, lastExportDirectory.getAbsolutePath());
    }

    /**
     * Gets the last directory that a user exported a playlist to.
     *
     * @return the last directory a user exported a playlist in or
     *         null if there is no such directory or the directory
     *         no longer exists.
     */
    protected File getLastExportDirectory() {
        File lastExportDirectory = null;

        Preferences preferences =
            Preferences.userNodeForPackage(this.getClass());
        String lastExportDirectoryString =
            preferences.get(LAST_EXPORT_DIRECTORY, null);

        if (lastExportDirectoryString != null) {
            lastExportDirectory = new File(lastExportDirectoryString);
        }

        if ((lastExportDirectory != null) && lastExportDirectory.exists()) {
            return lastExportDirectory;
        } else {
            return null;
        }
    }
}
