/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.swingui.license;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Frame;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.SwingUtilities;


/**
 * Basic Panel used to display the license file.
 *
 * @author Jordan Reed
 */
public class LicensePanel extends JPanel {
    /**
     * Constructs the basic license panel.
     */
    public LicensePanel() {
        setLayout(new BorderLayout());

        InputStream inputStream = getClass().getResourceAsStream("/LICENSE");
        BufferedInputStream bufferedInputStream =
            new BufferedInputStream(inputStream);
        InputStreamReader inputStreamReader =
            new InputStreamReader(bufferedInputStream);

        StringBuffer licenseBuffer = new StringBuffer(16384);

        try {
            char[] cbuf = new char[16384];
            int read = inputStreamReader.read(cbuf, 0, cbuf.length);

            while (read >= 0) {
                licenseBuffer.append(new String(cbuf));
                read = inputStreamReader.read(cbuf, 0, cbuf.length);
            }
        } catch (IOException e) {
            licenseBuffer = new StringBuffer("Error Loading License");
        } finally {
            try {
                inputStreamReader.close();
            } catch (IOException e) {
                // Do nothing.
            }
        }

        JTextArea licenseArea = new JTextArea(licenseBuffer.toString());
        JScrollPane scrollPane = new JScrollPane(licenseArea);
        add(scrollPane);
    }

    /**
     * Shows the license panel as modal to the given component.
     *
     * @param component the component to be modal to.
     */
    public static void showLicensePanel(Component component) {
        Frame parentFrame;

        if (component instanceof Frame) {
            parentFrame = (Frame) component;
        } else {
            parentFrame =
                (Frame) SwingUtilities.getAncestorOfClass(
                    Frame.class, component);
        }

        JDialog dialog =
            new JDialog(
                parentFrame, "GNU General Public License, version 2", true);

        dialog.setSize(parentFrame.getSize());
        dialog.setLocation(parentFrame.getLocation());

        dialog.getContentPane().add(new LicensePanel());
        dialog.show();
    }
}
