/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.swingui.menu;

import net.chaosserver.jtunes.event.FileOpenEvent;
import net.chaosserver.jtunes.event.JTunesApplicationEvent;
import net.chaosserver.jtunes.event.JTunesApplicationEventHandler;
import net.chaosserver.jtunes.event.JTunesApplicationEventListener;
import net.chaosserver.jtunes.event.PlayListCloseEvent;
import net.chaosserver.jtunes.event.PlayListExportEvent;
import net.chaosserver.jtunes.event.PlayListLoadedEvent;
import net.chaosserver.jtunes.event.ShowLicenseEvent;

import java.awt.Menu;
import java.awt.MenuItem;
import java.awt.MenuShortcut;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;


/**
 * Constructs the File Menu for the application.
 *
 * @author Jordan Reed
 */
public class FileMenu extends Menu implements ActionListener,
    JTunesApplicationEventListener {
    /** Name of the action action command fired for by the open menu item. */
    public static final String ACTION_OPEN =
        "net.chaosserver.jtunes.swingui.menu.FileMenu.ACTION_OPEN";

    /** Name of the action action command fired for by the export menu item. */
    public static final String ACTION_EXPORT =
        "net.chaosserver.jtunes.swingui.menu.FileMenu.ACTION_EXPORT";

    /** Name of the action action command fired for by the close menu item. */
    public static final String ACTION_CLOSE =
        "net.chaosserver.jtunes.swingui.menu.FileMenu.ACTION_CLOSE";

    /** Name of the action action command fired to show the license. */
    public static final String ACTION_SHOW_LICENSE =
        "net.chaosserver.jtunes.swingui.menu.FileMenu.ACTION_SHOW_LICENSE";

    /** Holds the open menu item. */
    protected MenuItem openMenuItem;

    /** Holds the export menu item. */
    protected MenuItem exportMenuItem;

    /** Holds the close menu item. */
    protected MenuItem closeMenuItem;

    /** Holds the show license menu item. */
    protected MenuItem showLicenseMenuItem;

    /**
     * Constructs the FileMenu.
     */
    public FileMenu() {
        super("File");
        JTunesApplicationEventHandler.getInstance()
                                     .addJTunesApplicationEventListener(this);

        openMenuItem = new MenuItem("Open Playlist");

        MenuShortcut openMenuShortcut = new MenuShortcut(KeyEvent.VK_O);
        openMenuItem.setShortcut(openMenuShortcut);
        openMenuItem.setActionCommand(ACTION_OPEN);
        openMenuItem.addActionListener(this);
        add(openMenuItem);

        exportMenuItem = new MenuItem("Export Playlist");

        MenuShortcut exportMenuShortcut = new MenuShortcut(KeyEvent.VK_X);
        exportMenuItem.setShortcut(exportMenuShortcut);
        exportMenuItem.setActionCommand(ACTION_EXPORT);
        exportMenuItem.addActionListener(this);
        exportMenuItem.setEnabled(false);
        add(exportMenuItem);

        closeMenuItem = new MenuItem("Close Playlist");

        MenuShortcut closeMenuShortcut = new MenuShortcut(KeyEvent.VK_W);
        closeMenuItem.setShortcut(closeMenuShortcut);
        closeMenuItem.setActionCommand(ACTION_CLOSE);
        closeMenuItem.addActionListener(this);
        closeMenuItem.setEnabled(false);
        add(closeMenuItem);

        add(new MenuItem("-"));

        showLicenseMenuItem = new MenuItem("Show License");
        showLicenseMenuItem.setActionCommand(ACTION_SHOW_LICENSE);
        showLicenseMenuItem.addActionListener(this);
        add(showLicenseMenuItem);
    }

    /**
     * Listens for actions fired by the menu commands and converts them
     * into application level events.
     *
     * @param evt events fired by the menu items
     */
    public void actionPerformed(ActionEvent evt) {
        if (ACTION_OPEN.equals(evt.getActionCommand())) {
            JTunesApplicationEventHandler.getInstance().fireEvent(
                new FileOpenEvent());
        } else if (ACTION_EXPORT.equals(evt.getActionCommand())) {
            JTunesApplicationEventHandler.getInstance().fireEvent(
                new PlayListExportEvent());
        } else if (ACTION_CLOSE.equals(evt.getActionCommand())) {
            JTunesApplicationEventHandler.getInstance().fireEvent(
                new PlayListCloseEvent());
        } else if (ACTION_SHOW_LICENSE.equals(evt.getActionCommand())) {
            JTunesApplicationEventHandler.getInstance().fireEvent(
                new ShowLicenseEvent());
        }
    }

    /**
     * Listens for application events and enables/disabled menu items
     * as needed.
     *
     * @param evt application event
     */
    public void eventPerformed(JTunesApplicationEvent evt) {
        if (evt instanceof PlayListLoadedEvent) {
            exportMenuItem.setEnabled(true);
            closeMenuItem.setEnabled(true);
        } else if (evt instanceof PlayListCloseEvent) {
            exportMenuItem.setEnabled(false);
            closeMenuItem.setEnabled(false);
        }
    }
}
