/*
 * jTunes
 *
 * Copyright (C) 2002-2003, Jordan Reed <reedjd@bitsmart.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package net.chaosserver.jtunes.swingui.playlist;

import net.chaosserver.jtunes.event.CopySongEvent;
import net.chaosserver.jtunes.event.FinishExportEvent;
import net.chaosserver.jtunes.event.JTunesApplicationEvent;
import net.chaosserver.jtunes.event.JTunesApplicationEventHandler;
import net.chaosserver.jtunes.event.JTunesApplicationEventListener;
import net.chaosserver.jtunes.playlist.PlayList;

import java.awt.BorderLayout;
import java.awt.Frame;

import javax.swing.JDialog;
import javax.swing.JProgressBar;


/**
 * Modal dialog box used to display the progress of exporting the files
 * in a playlist to a new location.
 *
 * @author Jordan Reed
 */
public class ExportProgressDialog extends JDialog
    implements JTunesApplicationEventListener {
    /** Holds the playlist being exported. */
    protected PlayList playList;

    /** Holds the progress bar showing the current progress. */
    protected JProgressBar progressBar;

    /**
     * Constructs the dialog for a given playlist that is modal
     * to the owner.
     *
     * @param owner the owner of the playlist
     * @param playList the playlist being exported.
     */
    public ExportProgressDialog(Frame owner, PlayList playList) {
        super(owner, "Exporting Playlist", true);
        this.playList = playList;

        getContentPane().setLayout(new BorderLayout());

        progressBar = new JProgressBar(1, playList.size() + 1);
        getContentPane().add(progressBar);
        pack();

        JTunesApplicationEventHandler.getInstance()
                                     .addJTunesApplicationEventListener(this);
    }

    /**
     * Listens for export events to update the status of the
     * display.
     *
     * @param evt applicationEvent being fired
     */
    public void eventPerformed(JTunesApplicationEvent evt) {
        if (evt instanceof FinishExportEvent) {
            dispose();
            JTunesApplicationEventHandler.getInstance()
                                         .removeJTunesApplicationEventListener(
                this);
        } else if (evt instanceof CopySongEvent) {
            progressBar.setValue(progressBar.getValue() + 1);
        }
    }
}
